DEFAULT = 'www'

INITIALIZATION_MESSAGE = '\n-------------- Initializing `ONCE` Func(s) --------------'

METHOD_CONNECT = CONNECT = 'CONNECT'
METHOD_DELETE = DELETE = 'DELETE'
METHOD_GET = GET = 'GET'
METHOD_HEAD = HEAD = 'HEAD'
METHOD_OPTIONS = OPTIONS = 'OPTIONS'
METHOD_PATCH = PATCH = 'PATCH'
METHOD_POST = POST = 'POST'
METHOD_PUT = PUT = 'PUT'
METHOD_SOCKET = METHOD_WEBSOCKET = SOCKET = 'SOCKET'
METHOD_TRACE = TRACE = 'TRACE'
METHODS = [GET, HEAD, POST, PUT, PATCH, CONNECT, TRACE, DELETE, OPTIONS]

MESSAGE_NOT_FOUND = 'Not found'

SHUTDOWN = 'shutdown'
STARTUP = 'startup'

STATUS_OK = OK = 200
STATUS_CREATED = CREATED = 201
STATUS_NOT_FOUND = NOT_FOUND = 404

URL_ERROR_MESSAGE = 'Malformed route detected, all routes must start with a `/`'

WILDCARD = '*'
